##  Are Fact Sheet Subtypes Configurable?
We're refining several roadmap items, which aim to bring the current configuration capabilities on fact sheet types to subtypes. Examples include configuring conditional fields, configuring subtypes, configuring the authorization model for subtypes, and supporting the renaming of fact sheet types.
